require "roda"

class Server < Roda
  class << self
    def gen(css=nil, js=nil, **kwargs, &block)
      Class.new Server do |c|
        unless kwargs.empty?
          c.plugin :sprockets, root: __dir__, **kwargs
        end

        if css || js
          c.route do |r|
            r.sprockets

            r.root do
              out = ""
              out += stylesheet_tag(css) if css
              out += javascript_tag(js) if js
              out
            end
          end
        end

        yield(c) if block_given?
      end
    end

    # Slightly adapted from https://github.com/jeremyevans/roda/blob/master/spec/spec_helper.rb
    def req(path = '/', env = {})
      env['PATH_INFO'] = path.dup
      env = {"REQUEST_METHOD" => "GET", "PATH_INFO" => "/", "SCRIPT_NAME" => ""}.merge(env)
      Response.new(*self.call(env))
    end
  end

  class Response
    def initialize(status, headers, body)
      @status, @headers, @body = status, headers, body
    end

    def ok?
      status == 200
    end

    attr_reader :status, :headers

    def body
      @body&.join
    end

    def js_path
      body =~ /<script src="(.*?)"/
      $1
    end

    def css_path
      body =~ /<link rel="stylesheet" type="text\/css" href="(.*?)"/
      $1
    end

    def not_modified?
      status == 304 &&
        (body.nil? || body.empty?) &&
        !headers.key?("Content-Length") &&
        !headers.key?("Content-Type")
    end
  end
end